Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6121)

Unified Diff: chrome/browser/ui/window_sizer/window_sizer_common_unittest.h

Issue 424463002: Makes a window that has been resized to maximized bounds, then maximized and then restored shrink (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Maximizes a window that has been resized to maximized bounds (nits, restricts to tabbed browsers) Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/window_sizer/window_sizer_common_unittest.h
diff --git a/chrome/browser/ui/window_sizer/window_sizer_common_unittest.h b/chrome/browser/ui/window_sizer/window_sizer_common_unittest.h
index 4e5d4b20b1fd7e72e9caa776f604e07bfd337957..f2c4fb6f8dc319f74310619904153a35fbd0ed7e 100644
--- a/chrome/browser/ui/window_sizer/window_sizer_common_unittest.h
+++ b/chrome/browser/ui/window_sizer/window_sizer_common_unittest.h
@@ -89,7 +89,7 @@ class TestStateProvider : public WindowSizer::StateProvider {
enum Source { DEFAULT, LAST_ACTIVE, PERSISTED, BOTH };
-// Set up the window bounds, monitor bounds, show states and more to get the
+// Sets up the window bounds, monitor bounds, show states and more to get the
// resulting |out_bounds| and |out_show_state| from the WindowSizer.
// |source| specifies which type of data gets set for the test: Either the
// last active window, the persisted value which was stored earlier, both or
@@ -108,7 +108,7 @@ void GetWindowBoundsAndShowState(const gfx::Rect& monitor1_bounds,
gfx::Rect* out_bounds,
ui::WindowShowState* out_show_state);
-// Set up the window bounds, monitor bounds, and work area to get the
+// Sets up the window bounds, monitor bounds, and work area to get the
// resulting |out_bounds| from the WindowSizer.
// |source| specifies which type of data gets set for the test: Either the
// last active window, the persisted value which was stored earlier, both or
@@ -124,14 +124,16 @@ void GetWindowBounds(const gfx::Rect& monitor1_bounds,
const gfx::Rect& passed_in,
gfx::Rect* out_bounds);
// Set up the various show states and get the resulting show state from
// the WindowSizer.
// The |display_config| is the primary display configuration used.
ui::WindowShowState GetWindowShowState(
ui::WindowShowState show_state_persisted,
ui::WindowShowState show_state_last,
Source source,
const Browser* browser,
+ const gfx::Rect& bounds,
const gfx::Rect& display_config);
#endif // CHROME_BROWSER_UI_WINDOW_SIZER_WINDOW_SIZER_COMMON_UNITTEST_H_
@@ -124,14 +124,16 @@ void GetWindowBounds(const gfx::Rect& monitor1_bounds,
const gfx::Rect& passed_in,
gfx::Rect* out_bounds);
-// Set up the various show states and get the resulting show state from
-// the WindowSizer.
-// The |display_config| is the primary display configuration used.
+// Sets up the window |bounds| and various system states which have an influence
+// on the WindowSizer and then determines the resulting show state from it.
+// |bounds| specifies the |browser| last or persistent bounds depending on
+// |source|. The |display_config| is the primary display configuration used.
ui::WindowShowState GetWindowShowState(
ui::WindowShowState show_state_persisted,

Powered by Google App Engine
This is Rietveld 408576698